@@ -91,8 +91,9 @@ def interceptor(rn_environ, *args, **kwargs):
     
     ctx.host = environ.get('HTTP_HOST', '').split(':')[0]
     ctx.service_name = environ.get('PATH_INFO', '')
-    
-    ctx.remoteIp = environ.get('REMOTE_ADDR', '')
+
+    ctx.remoteIp = userid_util.getRemoteAddr(args)
+
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
     ctx.referer = environ.get('HTTP_REFERER''', '')
 
@@ -170,11 +171,12 @@ def interceptor_error(status_code, errors):
         for stack in traceback.extract_stack(frame):
             line = stack[0]
             line_num = stack[1]
-            
+            method_name = stack[2]
+
             if line.find('/whatap/trace') > -1 or line.find(
                     '/threading.py') > -1:
                 continue
-            error += '{} (line {})\n'.format(line, line_num)
+            error += '{} ({}:{})\n'.format(method_name, line, line_num)
         
         errors.append(error)
         
@@ -200,15 +202,21 @@ def interceptor_step_error(e):
     for stack in traceback.extract_stack(frame):
         line = stack[0]
         line_num = stack[1]
+        method_name = stack[2]
         
         if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
             continue
-        error += '{} (line {})\n'.format(line, line_num)
+        error += '{} ({}:{})\n'.format(method_name,line, line_num)
     
     errors.append(error)
     # errors.append(''.join(traceback.format_list(traceback.extract_stack(sys._current_frames()[ctx.thread.ident]))))
     UdpSession.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
 
+    if conf.profile_exception_stack:
+        desc = '\n'.join(errors)
+        datas = [' ', ' ', desc]
+        ctx.start_time = DateUtil.nowSystem()
+        UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
