@@ -26,6 +26,7 @@ DEFINITION = {
         ('MySQLdb', 'instrument_MySQLdb'),
         ('MySQLdb.cursors', 'instrument_MySQLdb_cursors'),
         ('pymysql', 'instrument_pymysql'),
+        ('pymysql.cursors', 'instrument_pymysql_cursors'),
     ],
     'database_postgresql': [
         ('psycopg2', 'instrument_psycopg2'),
@@ -61,5 +62,17 @@ DEFINITION = {
     ],
     'application_tornado': [
         ('tornado.web', 'instrument'),
-    ]
+    ],
+    'application_celery': [
+        # ('celery.task.base', 'instrument_task_base'),
+        #('celery.app.task', 'instrument_app_task'),
+        #('celery.worker', 'instrument_celery_worker'),
+        #('celery.concurrency.processes', 'instrument_celery_worker'),
+        #('celery.concurrency.prefork', 'instrument_celery_worker'),
+        ('celery.execute.trace', 'instrument_celery_execute_trace'),
+        ('celery.task.trace', 'instrument_celery_execute_trace'),
+        ('celery.app.trace', 'instrument_celery_execute_trace'),
+        #('billiard.pool', 'instrument_billiard_pool'),
+    ],
+
 }
